import { Action, ActionRequest } from '../../models/action';
export declare class BlockStorageActionService {
    /**
     * Attach a Block Storage volume to a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'attach',
     *   droplet_id: 11612190,
     *   region: 'nyc1'
     * }
     * const action = await client.blockStorageActions
     *    .attachVolumeToDroplet('volume-id', request);
     * ```
     */
    attachVolumeToDroplet(volumeId: string, actionRequest: ActionRequest): Promise<Action>;
    /**
     * Attach a Block Storage volume to a droplet using the volume name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'attach',
     *   volume_name: 'example',
     *   region: 'nyc1',
     *   droplet_id: 116121901
     * }
     * const action = await client.blockStorageActions
     *    .attachVolumeToDropletByName(request);
     * ```
     */
    attachVolumeToDropletByName(actionRequest: ActionRequest): Promise<Action>;
    /**
     * Detach a Block Storage volume from a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'detach',
     *   droplet_id: 11612190,
     *   region: 'nyc1'
     * }
     * const action = await client.blockStorageActions
     *    .detachVolumeFromDroplet('volume-id', request);
     * ```
     */
    detachVolumeFromDroplet(volumeId: string, actionRequest: ActionRequest): Promise<Action>;
    /**
     * Detach a Block Storage volume from a droplet using the volume name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'detach',
     *   volume_name: 'example',
     *   region: 'nyc1',
     *   droplet_id: 116121901
     * }
     * const action = await client.blockStorageActions
     *    .detachVolumeFromDropletByName(request);
     * ```
     */
    detachVolumeFromDropletByName(actionRequest: ActionRequest): Promise<Action>;
    /**
     * Resize a Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'resize',
     *   size_gigabytes: 100,
     *   region: 'nyc1'
     * }
     * const action = await client.blockStorageActions
     *    .resizeVolume('volume-id', request);
     * ```
     */
    resizeVolume(volumeId: string, actionRequest: ActionRequest): Promise<Action>;
    /**
     * List all actions that have been executed on the specified volume.
     * Limited to 25 actions per page unless otherwise specified.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.blockStorageActions.getAllVolumeActions('volume-id');
     * // Paginate actions, 10 per page, starting on page 1
     * actions = await client.blockStorageActions
     *    .getAllVolumeActions('volume-id', 10, 1);
     * ```
     */
    getAllVolumeActions(volumeId: string, perPage?: number, page?: number): Promise<Action[]>;
    /**
     * Get an existing volume action based on the provided ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.blockStorageActions
     *    .getExistingVolumeAction('volume-id', 'action-id');
     * ```
     */
    getExistingVolumeAction(volumeId: string, actionId: number): Promise<Action>;
    private attachActionIsValid;
    private attachActionByNameIsValid;
    private resizeActionIsValid;
}
