"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockStorageActionService = void 0;
const axios_instance_1 = require("../../axios-instance");
class BlockStorageActionService {
    /**
     * Attach a Block Storage volume to a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'attach',
     *   droplet_id: 11612190,
     *   region: 'nyc1'
     * }
     * const action = await client.blockStorageActions
     *    .attachVolumeToDroplet('volume-id', request);
     * ```
     */
    attachVolumeToDroplet(volumeId, actionRequest) {
        if (!this.attachActionIsValid(actionRequest)) {
            throw new Error('Required fields missing from Action Object');
        }
        return axios_instance_1.instance
            .post(`/volumes/${volumeId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Attach a Block Storage volume to a droplet using the volume name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'attach',
     *   volume_name: 'example',
     *   region: 'nyc1',
     *   droplet_id: 116121901
     * }
     * const action = await client.blockStorageActions
     *    .attachVolumeToDropletByName(request);
     * ```
     */
    attachVolumeToDropletByName(actionRequest) {
        if (!this.attachActionByNameIsValid(actionRequest)) {
            throw new Error('Required fields missing from Action Object');
        }
        return axios_instance_1.instance
            .post(`/volumes/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Detach a Block Storage volume from a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'detach',
     *   droplet_id: 11612190,
     *   region: 'nyc1'
     * }
     * const action = await client.blockStorageActions
     *    .detachVolumeFromDroplet('volume-id', request);
     * ```
     */
    detachVolumeFromDroplet(volumeId, actionRequest) {
        if (!this.attachActionIsValid(actionRequest)) {
            throw new Error('Required fields missing from Action Object');
        }
        return axios_instance_1.instance
            .post(`/volumes/${volumeId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Detach a Block Storage volume from a droplet using the volume name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'detach',
     *   volume_name: 'example',
     *   region: 'nyc1',
     *   droplet_id: 116121901
     * }
     * const action = await client.blockStorageActions
     *    .detachVolumeFromDropletByName(request);
     * ```
     */
    detachVolumeFromDropletByName(actionRequest) {
        if (!this.attachActionByNameIsValid(actionRequest)) {
            throw new Error('Required fields missing from Action Object');
        }
        return axios_instance_1.instance
            .post(`/volumes/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Resize a Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'resize',
     *   size_gigabytes: 100,
     *   region: 'nyc1'
     * }
     * const action = await client.blockStorageActions
     *    .resizeVolume('volume-id', request);
     * ```
     */
    resizeVolume(volumeId, actionRequest) {
        if (!this.resizeActionIsValid(actionRequest)) {
            throw new Error('Required fields missing from Action Object');
        }
        return axios_instance_1.instance
            .post(`/volumes/${volumeId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * List all actions that have been executed on the specified volume.
     * Limited to 25 actions per page unless otherwise specified.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.blockStorageActions.getAllVolumeActions('volume-id');
     * // Paginate actions, 10 per page, starting on page 1
     * actions = await client.blockStorageActions
     *    .getAllVolumeActions('volume-id', 10, 1);
     * ```
     */
    getAllVolumeActions(volumeId, perPage, page) {
        page = page ? page : 1;
        perPage = perPage ? perPage : 25;
        return axios_instance_1.instance
            .get(`/volumes/${volumeId}/actions`, {
            params: {
                page,
                per_page: perPage
            }
        })
            .then(response => response.data.actions);
    }
    /**
     * Get an existing volume action based on the provided ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.blockStorageActions
     *    .getExistingVolumeAction('volume-id', 'action-id');
     * ```
     */
    getExistingVolumeAction(volumeId, actionId) {
        return axios_instance_1.instance
            .get(`/volumes/${volumeId}/actions/${actionId}`)
            .then(response => response.data.action);
    }
    ////////// Validation Methods //////////
    attachActionIsValid(action) {
        if (!action.type || !action.droplet_id) {
            return false;
        }
        return true;
    }
    attachActionByNameIsValid(action) {
        if (!this.attachActionIsValid(action) || !action.volume_name) {
            return false;
        }
        return true;
    }
    resizeActionIsValid(action) {
        if (!action.type || !action.size_gigabytes) {
            return false;
        }
        return true;
    }
}
exports.BlockStorageActionService = BlockStorageActionService;
//# sourceMappingURL=block-storage-actions.service.js.map