import { BlockStorage, BlockStorageRequest } from '../../models/block-storage';
import { Snapshot } from '../../models/snapshot';
export declare class BlockStorageService {
    /**
     * List all of the Block Storage volumes available on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const volumes = await client.blockStorage.getAllBlockStorage();
     * ```
     */
    getAllBlockStorage(): Promise<BlockStorage[]>;
    /**
     * Create a new Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   size_gigabytes: 10,
     *   name: 'example',
     *   description: 'Block store for examples',
     *   region: 'nyc1'
     * };
     * const volume = await client.blockStorage.createBlockStorage(request);
     * ```
     */
    createBlockStorage(volume: BlockStorageRequest): Promise<BlockStorage>;
    /**
     * Get a single Block Storage volume by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const volume = await client.blockStorage.getBlockStorageById('volume-id');
     * ```
     */
    getBlockStorageById(id: string): Promise<BlockStorage>;
    /**
     * Get Block Storage volumes by name and region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const volume = await client.blockStorage
     *    .getBlockStorageByName('volume-name', 'nyc1');
     * ```
     */
    getBlockStorageByName(name: string, regionSlug: string): Promise<BlockStorage[]>;
    /**
     * Get snapshots that have been created from a Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshots = await client.blockStorage
     *    .getSnapshotsForVolume('volume-id');
     * ```
     */
    getSnapshotsForVolume(id: string): Promise<Snapshot[]>;
    /**
     * Create a snapshot from a Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshot = await client.blockStorage
     *    .createSnapshotFromVolume('volume-id', 'my-new-snapshot');
     * ```
     */
    createSnapshotFromVolume(id: string, name: string): Promise<Snapshot>;
    /**
     * Delete a Block Storage volume by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.blockStorage.deleteBlockStorageById('volume-id');
     * ```
     */
    deleteBlockStorageById(id: string): Promise<void>;
    /**
     * Delete a Block Storage volume by name and region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.blockStorage.deleteBlockStorageByName('volume-name', 'nyc1');
     * ```
     */
    deleteBlockStorageByName(name: string, regionSlug: string): Promise<void>;
    private volumeIsValid;
}
