"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockStorageService = void 0;
const axios_instance_1 = require("../../axios-instance");
class BlockStorageService {
    /**
     * List all of the Block Storage volumes available on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const volumes = await client.blockStorage.getAllBlockStorage();
     * ```
     */
    getAllBlockStorage() {
        return axios_instance_1.instance.get(`/volumes`).then(response => response.data.volumes);
    }
    /**
     * Create a new Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   size_gigabytes: 10,
     *   name: 'example',
     *   description: 'Block store for examples',
     *   region: 'nyc1'
     * };
     * const volume = await client.blockStorage.createBlockStorage(request);
     * ```
     */
    createBlockStorage(volume) {
        if (!this.volumeIsValid(volume)) {
            throw new Error('Required fields missing from Block Storage Object');
        }
        return axios_instance_1.instance
            .post(`/volumes`, volume)
            .then(response => response.data.volume);
    }
    /**
     * Get a single Block Storage volume by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const volume = await client.blockStorage.getBlockStorageById('volume-id');
     * ```
     */
    getBlockStorageById(id) {
        return axios_instance_1.instance
            .get(`/volumes/${id}`)
            .then(response => response.data.volume);
    }
    /**
     * Get Block Storage volumes by name and region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const volume = await client.blockStorage
     *    .getBlockStorageByName('volume-name', 'nyc1');
     * ```
     */
    getBlockStorageByName(name, regionSlug) {
        return axios_instance_1.instance
            .get(`/volumes`, { params: { name, region: regionSlug } })
            .then(response => response.data.volumes);
    }
    /**
     * Get snapshots that have been created from a Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshots = await client.blockStorage
     *    .getSnapshotsForVolume('volume-id');
     * ```
     */
    getSnapshotsForVolume(id) {
        return axios_instance_1.instance
            .get(`/volumes/${id}/snapshots`)
            .then(response => response.data.snapshots);
    }
    /**
     * Create a snapshot from a Block Storage volume
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshot = await client.blockStorage
     *    .createSnapshotFromVolume('volume-id', 'my-new-snapshot');
     * ```
     */
    createSnapshotFromVolume(id, name) {
        return axios_instance_1.instance
            .post(`/volumes/${id}/snapshots`, { name })
            .then(response => response.data.snapshot);
    }
    /**
     * Delete a Block Storage volume by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.blockStorage.deleteBlockStorageById('volume-id');
     * ```
     */
    deleteBlockStorageById(id) {
        return axios_instance_1.instance.delete(`/volumes/${id}`);
    }
    /**
     * Delete a Block Storage volume by name and region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.blockStorage.deleteBlockStorageByName('volume-name', 'nyc1');
     * ```
     */
    deleteBlockStorageByName(name, regionSlug) {
        return axios_instance_1.instance.delete(`/volumes`, {
            params: { name, region: regionSlug }
        });
    }
    ////////// Validation Methods //////////
    volumeIsValid(vol) {
        if (!vol.size_gigabytes || !vol.name) {
            return false;
        }
        return true;
    }
}
exports.BlockStorageService = BlockStorageService;
//# sourceMappingURL=block-storage.service.js.map