import { CdnEndpoint, CdnEndpointRequest } from '../../models/cdn';
export declare class CdnService {
    /**
     * List all of the CDN endpoints available on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoints = await client.cdn.getAllEndpoints();
     * ```
     */
    getAllEndpoints(): Promise<CdnEndpoint[]>;
    /**
     * Get an existing CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoint = await client.cdn.getExistingEndpoint('endpoint-id');
     * ```
     */
    getExistingEndpoint(id: string): Promise<CdnEndpoint>;
    /**
     * Create a new CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "origin": "static-images.nyc3.digitaloceanspaces.com",
     *   "ttl": 3600
     * };
     * const endpoint = await client.cdn.createEndpoint(request);
     * ```
     */
    createEndpoint(endpoint: CdnEndpointRequest): Promise<CdnEndpoint>;
    /**
     * Update the ttl of an existing CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoint = await client.cdn.updateEndpoint('endpoint-id', 1800);
     * ```
     */
    updateEndpoint(id: string, ttl: number): Promise<CdnEndpoint>;
    /**
     * Delete an existing CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoint = await client.cdn.deleteEndpoint('endpoint-id');
     * ```
     */
    deleteEndpoint(id: string): Promise<void>;
    /**
     * Purge cached content from a CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const files = [
     *   'assets/img/hero.png',
     *   'assets/css/*'
     * ];
     * const endpoint = await client.cdn.purgeEndpointCache('endpoint-id', files);
     * ```
     */
    purgeEndpointCache(id: string, files: string[]): Promise<void>;
    private endpointIsValid;
}
