"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CdnService = void 0;
const axios_instance_1 = require("../../axios-instance");
class CdnService {
    /**
     * List all of the CDN endpoints available on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoints = await client.cdn.getAllEndpoints();
     * ```
     */
    getAllEndpoints() {
        return axios_instance_1.instance
            .get(`/cdn/endpoints`)
            .then(response => response.data.endpoints);
    }
    /**
     * Get an existing CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoint = await client.cdn.getExistingEndpoint('endpoint-id');
     * ```
     */
    getExistingEndpoint(id) {
        return axios_instance_1.instance
            .get(`/cdn/endpoints/${id}`)
            .then(response => response.data.endpoint);
    }
    /**
     * Create a new CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "origin": "static-images.nyc3.digitaloceanspaces.com",
     *   "ttl": 3600
     * };
     * const endpoint = await client.cdn.createEndpoint(request);
     * ```
     */
    createEndpoint(endpoint) {
        if (!this.endpointIsValid(endpoint)) {
            throw new Error('Required fields missing from Endpoint Object');
        }
        return axios_instance_1.instance
            .post(`/cdn/endpoints`, endpoint)
            .then(response => response.data.endpoint);
    }
    /**
     * Update the ttl of an existing CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoint = await client.cdn.updateEndpoint('endpoint-id', 1800);
     * ```
     */
    updateEndpoint(id, ttl) {
        return axios_instance_1.instance
            .put(`/cdn/endpoints/${id}`, { ttl })
            .then(response => response.data.endpoint);
    }
    /**
     * Delete an existing CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const endpoint = await client.cdn.deleteEndpoint('endpoint-id');
     * ```
     */
    deleteEndpoint(id) {
        return axios_instance_1.instance.delete(`/cdn/endpoints/${id}`);
    }
    /**
     * Purge cached content from a CDN endpoint
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const files = [
     *   'assets/img/hero.png',
     *   'assets/css/*'
     * ];
     * const endpoint = await client.cdn.purgeEndpointCache('endpoint-id', files);
     * ```
     */
    purgeEndpointCache(id, files) {
        return axios_instance_1.instance.delete(`/cdn/endpoints/${id}/cache`, {
            data: { files }
        });
    }
    ////////// Validation Methods //////////
    endpointIsValid(end) {
        if (!end.origin) {
            return false;
        }
        return true;
    }
}
exports.CdnService = CdnService;
//# sourceMappingURL=cdn.service.js.map