"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CertificateService = void 0;
const axios_instance_1 = require("../../axios-instance");
class CertificateService {
    /**
     * Upload a new SSL Certificate
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'web-cert-01',
     *   private_key: '-----BEGIN PRIVATE KEY-----...',
     *   leaf_certificate: '-----BEGIN CERTIFICATE-----...',
     *   certificate_chain: '-----BEGIN CERTIFICATE-----...'
     * };
     * const cert = await client.certificates.createCertificate(request);
     * ```
     */
    createCertificate(certificateRequest) {
        return axios_instance_1.instance
            .post(`/certificates`, certificateRequest)
            .then(response => response.data.certificate);
    }
    /**
     * Get information about an existing SSL Certificate
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const cert = await client.certificates.getExistingCertificate('cert-id');
     * ```
     */
    getExistingCertificate(certificateId) {
        return axios_instance_1.instance
            .get(`/certificates/${certificateId}`)
            .then(response => response.data.certificate);
    }
    /**
     * Get information about all SSL Certificates on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const certs = await client.certificates.getAllCertificates();
     * ```
     */
    getAllCertificates() {
        return axios_instance_1.instance
            .get(`/certificates`)
            .then(response => response.data.certificates);
    }
    /**
     * Delete a specific SSL Certificate from the provided ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.certificates.deleteCertificate('cert-id');
     * ```
     */
    deleteCertificate(certificateId) {
        return axios_instance_1.instance.delete(`/certificates/${certificateId}`);
    }
}
exports.CertificateService = CertificateService;
//# sourceMappingURL=certificate.service.js.map