import { DomainRecord, DomainRecordRequest } from '../../models/domain-record';
export declare class DomainRecordService {
    /**
     * Get all records configured for a domain
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const records = await client.domainRecords.getAllDomainRecords('example.com');
     * ```
     */
    getAllDomainRecords(domainName: string): Promise<DomainRecord[]>;
    /**
     * Create a new record for a domain
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   type: 'A',
     *   name: 'www',
     *   data: '162.10.66.0',
     *   priority: null,
     *   port: null,
     *   ttl: 1800,
     *   weight: null,
     *   flags: null,
     *   tag: null
     * };
     * const record = await client.domainRecords
     *    .createDomainRecord('example.com', request);
     * ```
     */
    createDomainRecord(domainName: string, domainRequest: DomainRecordRequest): Promise<DomainRecord>;
    /**
     * Get a specific existing domain record
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const record = await client.domainRecords
     *    .getExistingDomainRecord('example.com', 'record-id');
     * ```
     */
    getExistingDomainRecord(domainName: string, recordId: number): Promise<DomainRecord>;
    /**
     * Update an existing domain record
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   // Any valid domain record attribute can be changed
     *   name: 'blog'
     * };
     * const record = await client.domainRecords
     *    .updateDomainRecord('example.com', 'record-id', request);
     * ```
     */
    updateDomainRecord(domainName: string, recordId: number, domainRequest: DomainRecordRequest): Promise<DomainRecord>;
    /**
     * Delete a record for a domain
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.domainRecords.deleteDomainRecord('example.com', 'record-id');
     * ```
     */
    deleteDomainRecord(domainName: string, recordId: number): Promise<void>;
}
