"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainService = void 0;
const axios_instance_1 = require("../../axios-instance");
class DomainService {
    /**
     * Get a list of all the domains on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const domains = await client.domains.getAllDomains();
     * ```
     */
    getAllDomains() {
        return axios_instance_1.instance.get(`/domains`).then(response => response.data.domains);
    }
    /**
     * Create a new domain on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'example.com',
     *   ip_address: '1.2.3.4'
     * };
     * const domain = await client.domains.createDomain(request);
     * ```
     */
    createDomain(domainRequest) {
        return axios_instance_1.instance
            .post(`/domains`, domainRequest)
            .then(response => response.data.domain);
    }
    /**
     * Get information about a specific domain
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const domain = await client.domains.getExistingDomain('example.com');
     * ```
     */
    getExistingDomain(domainName) {
        return axios_instance_1.instance
            .get(`/domains/${domainName}`)
            .then(response => response.data.domain);
    }
    /**
     * Delete a specific domain from your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.domains.deleteDomain('example.com');
     * ```
     */
    deleteDomain(domainName) {
        return axios_instance_1.instance.delete(`/domains/${domainName}`);
    }
}
exports.DomainService = DomainService;
//# sourceMappingURL=domain.service.js.map