import { Action } from '../../models/action';
export declare class DropletActionService {
    /**
     * Enable backups on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.enableBackupsForDroplet('droplet-id');
     * ```
     */
    enableBackupsForDroplet(dropletId: number): Promise<Action>;
    /**
     * Disable backups on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.disableBackupsForDroplet('droplet-id');
     * ```
     */
    disableBackupsForDroplet(dropletId: number): Promise<Action>;
    /**
     * Reboot a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.rebootDroplet('droplet-id');
     * ```
     */
    rebootDroplet(dropletId: number): Promise<Action>;
    /**
     * Power cycle a droplet (power off then on)
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.powerCycleDroplet('droplet-id');
     * ```
     */
    powerCycleDroplet(dropletId: number): Promise<Action>;
    /**
     * Shutdown a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.shutdownDroplet('droplet-id');
     * ```
     */
    shutdownDroplet(dropletId: number): Promise<Action>;
    /**
     * Power off a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.powerOffDroplet('droplet-id');
     * ```
     */
    powerOffDroplet(dropletId: number): Promise<Action>;
    /**
     * Power on a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.powerOnDroplet('droplet-id');
     * ```
     */
    powerOnDroplet(dropletId: number): Promise<Action>;
    /**
     * Restore a droplet using a backup image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.restoreDroplet('droplet-id', 12389723);
     * ```
     */
    restoreDroplet(dropletId: number, image: string | number): Promise<Action>;
    /**
     * Reset the password for a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.passwordResetDroplet('droplet-id');
     * ```
     */
    passwordResetDroplet(dropletId: number): Promise<Action>;
    /**
     * Resize a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .resizeDroplet('droplet-id', true, '1gb');
     * ```
     */
    resizeDroplet(dropletId: number, resizeDisk: boolean, size: string): Promise<Action>;
    /**
     * Rebuild a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .rebuildDroplet('droplet-id', 'ubuntu-16-04-x64');
     * ```
     */
    rebuildDroplet(dropletId: number, image: string | number): Promise<Action>;
    /**
     * Rename a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .renameDroplet('droplet-id', 'nifty-new-name');
     * ```
     */
    renameDroplet(dropletId: number, name: string): Promise<Action>;
    /**
     * Change the kernel of a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .renameDroplet('droplet-id', 991);
     * ```
     */
    changeDropletKernel(dropletId: number, kernelId: number): Promise<Action>;
    /**
     * Enable IPv6 networking on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.enableIPv6('droplet-id');
     * ```
     */
    enableIPv6(dropletId: number): Promise<Action>;
    /**
     * Enable private networking on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.enablePrivateNetworking('droplet-id');
     * ```
     */
    enablePrivateNetworking(dropletId: number): Promise<Action>;
    /**
     * Take a snapshot of a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .snapshotDroplet('droplet-id', 'Nifty New Snapshot');
     * ```
     */
    snapshotDroplet(dropletId: number, name: string): Promise<Action>;
    /**
     * Get a specific droplet action
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .getExistingDropletAction('droplet-id', 'action-id');
     * ```
     */
    getExistingDropletAction(dropletId: number, actionId: number): Promise<Action>;
}
