"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DropletActionService = void 0;
const axios_instance_1 = require("../../axios-instance");
class DropletActionService {
    /**
     * Enable backups on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.enableBackupsForDroplet('droplet-id');
     * ```
     */
    enableBackupsForDroplet(dropletId) {
        const actionRequest = {
            type: 'enable_backups'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Disable backups on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.disableBackupsForDroplet('droplet-id');
     * ```
     */
    disableBackupsForDroplet(dropletId) {
        const actionRequest = {
            type: 'disable_backups'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Reboot a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.rebootDroplet('droplet-id');
     * ```
     */
    rebootDroplet(dropletId) {
        const actionRequest = {
            type: 'reboot'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Power cycle a droplet (power off then on)
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.powerCycleDroplet('droplet-id');
     * ```
     */
    powerCycleDroplet(dropletId) {
        const actionRequest = {
            type: 'power_cycle'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Shutdown a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.shutdownDroplet('droplet-id');
     * ```
     */
    shutdownDroplet(dropletId) {
        const actionRequest = {
            type: 'shutdown'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Power off a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.powerOffDroplet('droplet-id');
     * ```
     */
    powerOffDroplet(dropletId) {
        const actionRequest = {
            type: 'power_off'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Power on a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.powerOnDroplet('droplet-id');
     * ```
     */
    powerOnDroplet(dropletId) {
        const actionRequest = {
            type: 'power_on'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Restore a droplet using a backup image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.restoreDroplet('droplet-id', 12389723);
     * ```
     */
    restoreDroplet(dropletId, image) {
        const actionRequest = {
            image,
            type: 'restore'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Reset the password for a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.passwordResetDroplet('droplet-id');
     * ```
     */
    passwordResetDroplet(dropletId) {
        const actionRequest = {
            type: 'password_reset'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Resize a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .resizeDroplet('droplet-id', true, '1gb');
     * ```
     */
    resizeDroplet(dropletId, resizeDisk, size) {
        const actionRequest = {
            disk: resizeDisk,
            size,
            type: 'password_reset'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Rebuild a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .rebuildDroplet('droplet-id', 'ubuntu-16-04-x64');
     * ```
     */
    rebuildDroplet(dropletId, image) {
        const actionRequest = {
            image,
            type: 'rebuild'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Rename a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .renameDroplet('droplet-id', 'nifty-new-name');
     * ```
     */
    renameDroplet(dropletId, name) {
        const actionRequest = {
            name,
            type: 'rename'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Change the kernel of a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .renameDroplet('droplet-id', 991);
     * ```
     */
    changeDropletKernel(dropletId, kernelId) {
        const actionRequest = {
            kernel: kernelId,
            type: 'change_kernel'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Enable IPv6 networking on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.enableIPv6('droplet-id');
     * ```
     */
    enableIPv6(dropletId) {
        const actionRequest = {
            type: 'enable_ipv6'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Enable private networking on an existing droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions.enablePrivateNetworking('droplet-id');
     * ```
     */
    enablePrivateNetworking(dropletId) {
        const actionRequest = {
            type: 'enable_private_networking'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    /**
     * Take a snapshot of a droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .snapshotDroplet('droplet-id', 'Nifty New Snapshot');
     * ```
     */
    snapshotDroplet(dropletId, name) {
        const actionRequest = {
            name,
            type: 'snapshot'
        };
        return axios_instance_1.instance
            .post(`/droplets/${dropletId}/actions`, actionRequest)
            .then(response => response.data.action);
    }
    // TODO: Implement the bulk action method, Acting on Tagged Droplets
    /**
     * Get a specific droplet action
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.dropletActions
     *    .getExistingDropletAction('droplet-id', 'action-id');
     * ```
     */
    getExistingDropletAction(dropletId, actionId) {
        return axios_instance_1.instance
            .get(`/droplets/${dropletId}/actions/${actionId}`)
            .then(response => response.data.action);
    }
}
exports.DropletActionService = DropletActionService;
//# sourceMappingURL=droplet-actions.service.js.map