import { Action } from '../../models/action';
import { Backup } from '../../models/backup';
import { Droplet, DropletRequest } from '../../models/droplet';
import { Kernel } from '../../models/kernel';
import { Snapshot } from '../../models/snapshot';
export declare class DropletService {
    /**
     * Create a new droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'example.com',
     *   region: 'nyc3',
     *   size: 's-1vcpu-1gb',
     *   image: 'ubuntu-16-04-x64',
     *   ssh_keys: null,
     *   backups: false,
     *   ipv6: true,
     *   user_data: null,
     *   private_networking: null,
     *   volumes: null,
     *   tags: [
     *     'web'
     *   ]
     * };
     * const droplet = await client.droplets.createNewDroplet(request);
     * ```
     */
    createNewDroplet(dropletRequest: DropletRequest): Promise<Droplet>;
    /**
     * Create multiple droplets with the same specs but different names
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   names: [
     *     'sub-01.example.com',
     *     'sub-02.example.com'
     *   ],
     *   region: 'nyc3',
     *   size: 's-1vcpu-1gb',
     *   image: 'ubuntu-16-04-x64',
     *   ssh_keys: null,
     *   backups: false,
     *   ipv6: true,
     *   user_data: null,
     *   private_networking: null,
     *   tags: [
     *     'web'
     *   ]
     * };
     * const droplets = await client.droplets.createMultipleDroplets(request);
     * ```
     */
    createMultipleDroplets(dropletsRequest: DropletRequest): Promise<Droplet[]>;
    /**
     * Get a specific existing droplet by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const droplet = await client.droplets.getExistingDroplet('droplet-id');
     * ```
     */
    getExistingDroplet(dropletId: number): Promise<Droplet>;
    /**
     * Get all droplets on the account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const droplets = await client.droplets.getAllDroplets();
     * ```
     */
    getAllDroplets(): Promise<Droplet[]>;
    /**
     * Get all droplets on the account that has a given tag
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const droplets = await client.droplets.getDropletsByTag('tag-name');
     * ```
     */
    getDropletsByTag(tag: string): Promise<Droplet[]>;
    /**
     * Retrieve a list of all kernels available to a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const kernels = await client.droplets.getAvailableKernelsForDroplet('droplet-id');
     * ```
     */
    getAvailableKernelsForDroplet(dropletId: number): Promise<Kernel[]>;
    /**
     * Retrieve the snapshots that have been created from a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshots = await client.droplets.getSnapshotsForDroplet('droplet-id');
     * ```
     */
    getSnapshotsForDroplet(dropletId: number): Promise<Snapshot[]>;
    /**
     * Retrieve any backups associated with a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const backups = await client.droplets.getBackupsForDroplet('droplet-id');
     * ```
     */
    getBackupsForDroplet(dropletId: number): Promise<Backup[]>;
    /**
     * Retrieve all actions that have been executed on a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.droplets.getDropletActions('droplet-id');
     * ```
     */
    getDropletActions(dropletId: number): Promise<Action[]>;
    /**
     * Delete a specific droplet by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.droplets.deleteDroplet('droplet-id');
     * ```
     */
    deleteDroplet(dropletId: number): Promise<void>;
    /**
     * Delete Droplets by a tag
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.droplets.deleteDropletsByTag('tag');
     * ```
     */
    deleteDropletsByTag(tag: string): Promise<void>;
    /**
     * Retrieve a list of Droplets that are running on the same physical server
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const droplets = await client.droplets.getNeighborsForDroplet('droplet-id');
     * ```
     */
    getNeighborsForDroplet(dropletId: number): Promise<Droplet[]>;
    /**
     * Retrieve a list of any Droplets that are running on the same physical hardware
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const droplets = await client.droplets.getDropletNeighbors();
     * ```
     */
    getDropletNeighbors(): Promise<Droplet[][]>;
}
