"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FloatingIPActionService = void 0;
const axios_instance_1 = require("../../axios-instance");
class FloatingIPActionService {
    /**
     * Assign an existing Floating IP to a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.floatingIPActions
     *    .assignFloatingIPToDroplet('1.2.3.4', 'droplet-id');
     * ```
     */
    assignFloatingIPToDroplet(floatingIPAddress, dropletId) {
        const request = {
            droplet_id: dropletId,
            type: 'assign'
        };
        return axios_instance_1.instance
            .post(`/floating_ips/${floatingIPAddress}/actions`, request)
            .then(response => response.data.action);
    }
    /**
     * Unassign an existing Floating IP
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.floatingIPActions
     *    .unassignFloatingIP('1.2.3.4');
     * ```
     */
    unassignFloatingIP(floatingIPAddress) {
        const request = {
            type: 'unassign'
        };
        return axios_instance_1.instance
            .post(`/floating_ips/${floatingIPAddress}/actions`, request)
            .then(response => response.data.action);
    }
    /**
     * Retrieve all actions that have been executed on a Floating IP
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.floatingIPActions
     *    .getAllFloatingIPActions('1.2.3.4');
     * ```
     */
    getAllFloatingIPActions(floatingIPAddress) {
        return axios_instance_1.instance
            .get(`/floating_ips/${floatingIPAddress}/actions`)
            .then(response => response.data.actions);
    }
    /**
     * Retrieve the status of a Floating IP action
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.floatingIPActions
     *    .getExistingFloatingIPAction('1.2.3.4', 'action-id');
     * ```
     */
    getExistingFloatingIPAction(floatingIPAddress, actionId) {
        return axios_instance_1.instance
            .get(`/floating_ips/${floatingIPAddress}/actions/${actionId}`)
            .then(response => response.data.action);
    }
}
exports.FloatingIPActionService = FloatingIPActionService;
//# sourceMappingURL=floating-ip-actions.service.js.map