"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FloatingIPService = void 0;
const axios_instance_1 = require("../../axios-instance");
class FloatingIPService {
    /**
     * List all of the Floating IPs available on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIPs = await client.floatingIPs.getAllFloatingIPs();
     * ```
     */
    getAllFloatingIPs() {
        return axios_instance_1.instance
            .get(`/floating_ips`)
            .then(response => response.data.floating_ips);
    }
    /**
     * Create a new Floating IP assigned to a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIP =
     *    await client.floatingIPs.createFloatingIPForDroplet('droplet-id');
     * ```
     */
    createFloatingIPForDroplet(dropletId) {
        const request = { droplet_id: dropletId };
        return axios_instance_1.instance
            .post(`/floating_ips`, request)
            .then(response => response.data.floating_ip);
    }
    /**
     * Create a Floating IP reserved to a Region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIP =
     *    await client.floatingIPs.createFloatingIPForRegion('nyc3');
     * ```
     */
    createFloatingIPForRegion(region) {
        return axios_instance_1.instance
            .post(`/floating_ips`, { region })
            .then(response => response.data.floating_ip);
    }
    /**
     * Show information about an existing Floating IP
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIP =
     *    await client.floatingIPs.getExistingFloatingIP('1.2.3.4');
     * ```
     */
    getExistingFloatingIP(floatingIPAddress) {
        return axios_instance_1.instance
            .get(`/floating_ips/${floatingIPAddress}`)
            .then(response => response.data.floating_ip);
    }
    /**
     * Delete an existing Floating IP and remove it from your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.floatingIPs.deleteFloatingIP('1.2.3.4');
     * ```
     */
    deleteFloatingIP(floatingIPAddress) {
        return axios_instance_1.instance.delete(`/floating_ips/${floatingIPAddress}`);
    }
}
exports.FloatingIPService = FloatingIPService;
//# sourceMappingURL=floating-ip.service.js.map