import { Action } from '../../models/action';
import { Image } from '../../models/image';
export declare class ImageService {
    /**
     * Get all images on account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getAllImages();
     * ```
     */
    getAllImages(): Promise<Image[]>;
    /**
     * Get all distribution images
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getAllDistributionImages();
     * // Paginate images, 10 per page, starting on page 1
     * images = await client.images.getAllDistributionImages(10, 1);
     * ```
     */
    getAllDistributionImages(perPage?: number, page?: number): Promise<Image[]>;
    /**
     * Get all application images
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getAllApplicationImages();
     * // Paginate application images, 10 per page, starting on page 1
     * images = await client.images.getAllApplicationImages(10, 1);
     * ```
     */
    getAllApplicationImages(perPage?: number, page?: number): Promise<Image[]>;
    /**
     * Get the private images of a user
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getUserImages();
     * // Paginate user images, 10 per page, starting on page 1
     * images = await client.images.getUserImages(10, 1);
     * ```
     */
    getUserImages(perPage?: number, page?: number): Promise<Image[]>;
    /**
     * Get all actions that have been executed on an image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.images.getImageActions('image-id');
     * ```
     */
    getImageActions(imageId: number): Promise<Action[]>;
    /**
     * Get information about an image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const image = await client.images.getExistingImage('image-id');
     * ```
     */
    getExistingImage(imageId: number): Promise<Image>;
    /**
     * Get information about an image by image slug
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const image = await client.images.getExistingImageBySlug('image-slug');
     * ```
     */
    getExistingImageBySlug(imageSlug: string): Promise<Image>;
    /**
     * Update an image name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const image = await client.images.updateImageName('image-id', 'New Image Name');
     * ```
     */
    updateImageName(imageId: number, name: string): Promise<Image>;
    /**
     * Delete an image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.images.deleteImage('image-id');
     * ```
     */
    deleteImage(imageId: number): Promise<void>;
}
