"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageService = void 0;
const axios_instance_1 = require("../../axios-instance");
class ImageService {
    /**
     * Get all images on account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getAllImages();
     * ```
     */
    getAllImages() {
        return axios_instance_1.instance.get(`/images`).then(response => response.data.images);
    }
    /**
     * Get all distribution images
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getAllDistributionImages();
     * // Paginate images, 10 per page, starting on page 1
     * images = await client.images.getAllDistributionImages(10, 1);
     * ```
     */
    getAllDistributionImages(perPage, page) {
        page = page ? page : 1;
        perPage = perPage ? perPage : 25;
        return axios_instance_1.instance
            .get(`/images`, {
            params: { type: 'distribution', page, per_page: perPage }
        })
            .then(response => response.data.images);
    }
    /**
     * Get all application images
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getAllApplicationImages();
     * // Paginate application images, 10 per page, starting on page 1
     * images = await client.images.getAllApplicationImages(10, 1);
     * ```
     */
    getAllApplicationImages(perPage, page) {
        page = page ? page : 1;
        perPage = perPage ? perPage : 25;
        return axios_instance_1.instance
            .get(`/images`, {
            params: { type: 'application', page, per_page: perPage }
        })
            .then(response => response.data.images);
    }
    /**
     * Get the private images of a user
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const images = await client.images.getUserImages();
     * // Paginate user images, 10 per page, starting on page 1
     * images = await client.images.getUserImages(10, 1);
     * ```
     */
    getUserImages(perPage, page) {
        page = page ? page : 1;
        perPage = perPage ? perPage : 25;
        return axios_instance_1.instance
            .get(`/images`, {
            params: { private: true, page, per_page: perPage }
        })
            .then(response => response.data.images);
    }
    /**
     * Get all actions that have been executed on an image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.images.getImageActions('image-id');
     * ```
     */
    getImageActions(imageId) {
        return axios_instance_1.instance
            .get(`/images/${imageId}/actions`)
            .then(response => response.data.actions);
    }
    /**
     * Get information about an image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const image = await client.images.getExistingImage('image-id');
     * ```
     */
    getExistingImage(imageId) {
        return axios_instance_1.instance
            .get(`/images/${imageId}`)
            .then(response => response.data.image);
    }
    /**
     * Get information about an image by image slug
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const image = await client.images.getExistingImageBySlug('image-slug');
     * ```
     */
    getExistingImageBySlug(imageSlug) {
        return axios_instance_1.instance
            .get(`/images/${imageSlug}`)
            .then(response => response.data.image);
    }
    /**
     * Update an image name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const image = await client.images.updateImageName('image-id', 'New Image Name');
     * ```
     */
    updateImageName(imageId, name) {
        return axios_instance_1.instance
            .put(`/images/${imageId}`, { name })
            .then(response => response.data.image);
    }
    /**
     * Delete an image
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.images.deleteImage('image-id');
     * ```
     */
    deleteImage(imageId) {
        return axios_instance_1.instance.delete(`/images/${imageId}`);
    }
}
exports.ImageService = ImageService;
//# sourceMappingURL=image.service.js.map