import { KubernetesCluster, KubernetesClusterRequest, KubernetesOptions, KubernetesVersion, KubernetesWorkerNodePool } from '../../models/kubernetes-cluster';
export declare class KubernetesService {
    /**
     * Create a new kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "name": "prod-cluster-01",
     *   "region": "nyc1",
     *   "version": "1.14.1-do.4",
     *   "tags": [
     *     "production",
     *     "web-team"
     *   ],
     *   "node_pools": [
     *     {
     *       "size": "s-1vcpu-2gb",
     *       "count": 3,
     *       "name": "frontend-pool",
     *       "tags": [
     *         "frontend"
     *       ]
     *     },
     *     {
     *       "size": "c-4",
     *       "count": 2,
     *       "name": "backend-pool"
     *     }
     *   ]
     * };
     * const cluster = await client.kubernetes.createCluster(request);
     * ```
     */
    createCluster(cluster: KubernetesClusterRequest): Promise<KubernetesCluster>;
    /**
     * Get a specific existing kubernetes cluster by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const cluster = await client.kubernetes.getCluster('cluster-id');
     * ```
     */
    getCluster(clusterId: string): Promise<KubernetesCluster>;
    /**
     * Get all existing kubernetes clusters
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const clusters = await client.kubernetes.getAllClusters();
     * ```
     */
    getAllClusters(): Promise<KubernetesCluster[]>;
    /**
     * Update an existing kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "name": "stage-cluster-01",
     *   "tags": [
     *     "staging",
     *     "web-team"
     *   ]
     * };
     * const cluster = await client.kubernetes.updateCluster('cluster-id', request);
     * ```
     */
    updateCluster(clusterId: string, cluster: KubernetesCluster): Promise<KubernetesCluster>;
    /**
     * Get available upgrades for an existing kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const upgrades = await client.kubernetes.getAvailableUpgradesForCluster('cluster-id');
     * ```
     */
    getAvailableUpgradesForCluster(clusterId: string): Promise<KubernetesVersion[]>;
    /**
     * Upgrade the version of an existing kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.kubernetes.upgradeExistingCluster('cluster-id', "1.12.3-do.1");
     * ```
     */
    upgradeExistingCluster(clusterId: string, version: string): Promise<void>;
    /**
     * Delete an existing kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.kubernetes.deleteCluster('cluster-id');
     * ```
     */
    deleteCluster(clusterId: string): Promise<void>;
    /**
     * Get the contents of the kubeconfig yaml file for use with a Kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const kubeconfig = await client.kubernetes.getClusterKubeconfig('cluster-id');
     * ```
     */
    getClusterKubeconfig(clusterId: string): Promise<string>;
    /**
     * Get an existing node pool on a kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const nodePool = await client.kubernetes.getExistingNodePoolForCluster('cluster-id', 'pool-id');
     * ```
     */
    getExistingNodePoolForCluster(clusterId: string, poolId: string): Promise<KubernetesWorkerNodePool>;
    /**
     * Get all existing node pools on a kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const nodePools = await client.kubernetes.getAllNodePoolsForCluster('cluster-id');
     * ```
     */
    getAllNodePoolsForCluster(clusterId: string): Promise<KubernetesWorkerNodePool[]>;
    /**
     * Add a node pool to a kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "size": "s-2vcpu-4gb",
     *   "count": 1,
     *   "name": "pool-02",
     *   "tags": [
     *     "web"
     *   ]
     * };
     * const nodePool = await client.kubernetes.addNodePoolToCluster('cluster-id', request);
     * ```
     */
    addNodePoolToCluster(clusterId: string, nodePool: KubernetesWorkerNodePool): Promise<KubernetesWorkerNodePool>;
    /**
     * Update an existing node pool in a kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "name": "frontend",
     *   "count": 1,
     *   "tags": [
     *     "frontend"
     *   ]
     * };
     * const nodePool = await client.kubernetes.updateNodePoolForCluster('cluster-id', 'pool-id', request);
     * ```
     */
    updateNodePoolForCluster(clusterId: string, nodePoolId: string, nodePool: KubernetesWorkerNodePool): Promise<KubernetesWorkerNodePool>;
    /**
     * Delete an existing node pool from a kubernetes cluster
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.kubernetes.deleteNodePoolFromCluster('cluster-id', 'pool-id');
     * ```
     */
    deleteNodePoolFromCluster(clusterId: string, nodePoolId: string): Promise<void>;
    /**
     * Delete an existing node from a node pool in a kubernetes cluster.
     * Optionally specify to skip node draining or to replace with a new node after deletion.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.kubernetes.deleteNodeFromNodePoolForCluster('cluster-id', 'pool-id', 'node-id', false, false);
     * ```
     */
    deleteNodeFromNodePoolForCluster(clusterId: string, nodePoolId: string, nodeId: string, skipDrain?: boolean, replace?: boolean): Promise<void>;
    /**
     * Get available Kubernetes versions, regions that support Kubernetes, and the available node sizes.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const options = await client.kubernetes.getKubernetesOptions();
     * ```
     */
    getKubernetesOptions(): Promise<KubernetesOptions>;
}
