import { Project, ProjectResource, ProjectResourceParsedUrn } from '../../models/project';
export declare class ProjectService {
    /**
     * Get all projects on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const projects = await client.projects.getAllProjects();
     * ```
     */
    getAllProjects(): Promise<Project[]>;
    /**
     * Get an existing project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const project = await client.projects.getExistingProject('project-id');
     * ```
     */
    getExistingProject(id: string): Promise<Project>;
    /**
     * Get the default project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const project = await client.projects.getDefaultProject();
     * ```
     */
    getDefaultProject(): Promise<Project>;
    /**
     * Create a new project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "name": "my-web-api",
     *   "description": "My website API",
     *   "purpose": "Service or API",
     *   "environment": "Production"
     * };
     * const project = await client.projects.createProject(request);
     * ```
     */
    createProject(project: Project): Promise<Project>;
    /**
     * Update an existing project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "name": "my-web-api",
     *   "description": "My website API",
     *   "purpose": "Service or API",
     *   "environment": "Staging",
     *   "is_default": false
     * };
     * const project = await client.projects.updateProject('project-id', request);
     * ```
     */
    updateProject(id: string, project: Project): Promise<Project>;
    /**
     * Update the default project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   "name": "my-web-api",
     *   "description": "My website API",
     *   "purpose": "Service or API",
     *   "environment": "Staging",
     *   "is_default": true
     * };
     * const project = await client.projects.updateDefaultProject(request);
     * ```
     */
    updateDefaultProject(project: Project): Promise<Project>;
    /**
     * Delete an existing project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.projects.deleteProject('project-id');
     * ```
     */
    deleteProject(id: string): Promise<void>;
    /**
     * Get all resources attached to a specific project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const resources = await client.projects.getProjectResources('project-id');
     * ```
     */
    getProjectResources(id: string): Promise<ProjectResource[]>;
    /**
     * Get all resources attached to the default project
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const resources = await client.projects.getDefaultProjectResources();
     * ```
     */
    getDefaultProjectResources(): Promise<ProjectResource[]>;
    /**
     * Assign resources to an existing project
     *
     * ### Example
     * ```js
     * import { DigitalOcean, RESOURCE_PREFIX } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const dropletId = 1;
     * const ip = '192.168.99.100';
     * // Build resource urns using RESOURCE_PREFIX constant provided.
     * const resources = [
     *    `${RESOURCE_PREFIX.DROPLET}${dropletId}`, // 'do:droplet:1'
     *    `${RESOURCE_PREFIX.FLOATING_IP}${ip}`     // 'do:floatingip:192.168.99.100'
     * ];
     * const resources = await client.projects
     *    .assignResourcesToProject('project-id', resources);
     * ```
     */
    assignResourcesToProject(id: string, resources: string[]): Promise<ProjectResource[]>;
    /**
     * Assign resources to the default project
     *
     * ### Example
     * ```js
     * import { DigitalOcean, RESOURCE_PREFIX } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const dropletId = 1;
     * const ip = '192.168.99.100';
     * // Build resource urns using RESOURCE_PREFIX constant provided.
     * const resources = [
     *    `${RESOURCE_PREFIX.DROPLET}${dropletId}`, // 'do:droplet:1'
     *    `${RESOURCE_PREFIX.FLOATING_IP}${ip}`     // 'do:floatingip:192.168.99.100'
     * ];
     * const resources = await client.projects
     *    .assignResourcesToDefaultProject(resources);
     * ```
     */
    assignResourcesToDefaultProject(resources: string[]): Promise<ProjectResource[]>;
    /**
     * Parses a Project Resource URN into its various parts
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const urn = 'do:droplet:4126873';
     * const resource = await client.projects
     *    .parseProjectResourceUrn(urn);
     * ```
     */
    parseProjectResourceUrn(urn: string): ProjectResourceParsedUrn;
    private projectIsValid;
    private createProjectIsValid;
    private purposeIsValid;
}
