"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SnapshotService = void 0;
const axios_instance_1 = require("../../axios-instance");
class SnapshotService {
    /**
     * Get all snapshots on the account.
     * Optionally provide a resource type to filter snapshots.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * // Get all snapshots
     * const snapshots = await client.snapshots.getSnapshots();
     * // Get all droplet snapshots
     * snapshots = await client.snapshots.getSnapshots('droplet');
     * // Get all volume snapshots
     * snapshots = await client.snapshots.getSnapshots('volume');
     * ```
     */
    getSnapshots(resourceType) {
        const params = {};
        if (resourceType && resourceType !== 'all') {
            params['resource_type'] = resourceType;
        }
        return axios_instance_1.instance
            .get(`/snapshots`, { params })
            .then(response => response.data.snapshots);
    }
    /**
     * Get a specific existing snapshot by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshot = await client.snapshots.getSnapshotById('snapshot-id');
     * ```
     */
    getSnapshotById(snapshotId) {
        return axios_instance_1.instance
            .get(`/snapshots/${snapshotId}`)
            .then(response => response.data.snapshot);
    }
    /**
     * Delete a specific snapshot by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.snapshots.deleteSnapshot('snapshot-id');
     * ```
     */
    deleteSnapshot(snapshotId) {
        return axios_instance_1.instance.delete(`/snapshots/${snapshotId}`);
    }
}
exports.SnapshotService = SnapshotService;
//# sourceMappingURL=snapshot.service.js.map