import { SshKey } from '../../models/ssh-key';
export declare class SshService {
    /**
     * Get all ssh keys on account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const keys = await client.ssh.getAllKeys();
     * ```
     */
    getAllKeys(): Promise<SshKey[]>;
    /**
     * Create new ssh key
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'My SSH Public Key',
     *   public_key: 'ssh-rsa abcdef.... example'
     * };
     * const key = await client.ssh.createNewKey(request);
     * ```
     */
    createNewKey(key: SshKey): Promise<SshKey>;
    /**
     * Get existing ssh key from id
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const key = await client.ssh.getExistingKey('id-or-fingerprint');
     * ```
     */
    getExistingKey(idOrFingerprint: string): Promise<SshKey>;
    /**
     * Update ssh key
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'Renamed SSH Key'
     * };
     * const key = await client.ssh.updateKey('id-or-fingerprint', request);
     * ```
     */
    updateKey(idOrFingerprint: string, key: SshKey): Promise<SshKey>;
    /**
     * Delete ssh key
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.ssh.deleteKey('id-or-fingerprint');
     * ```
     */
    deleteKey(idOrFingerprint: string): Promise<void>;
}
