"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SshService = void 0;
const axios_instance_1 = require("../../axios-instance");
class SshService {
    /**
     * Get all ssh keys on account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const keys = await client.ssh.getAllKeys();
     * ```
     */
    getAllKeys() {
        return axios_instance_1.instance
            .get(`/account/keys`)
            .then(response => response.data.ssh_keys);
    }
    /**
     * Create new ssh key
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'My SSH Public Key',
     *   public_key: 'ssh-rsa abcdef.... example'
     * };
     * const key = await client.ssh.createNewKey(request);
     * ```
     */
    createNewKey(key) {
        return axios_instance_1.instance
            .post(`/account/keys`, key)
            .then(response => response.data.ssh_key);
    }
    /**
     * Get existing ssh key from id
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const key = await client.ssh.getExistingKey('id-or-fingerprint');
     * ```
     */
    getExistingKey(idOrFingerprint) {
        return axios_instance_1.instance
            .get(`/account/keys/${idOrFingerprint}`)
            .then(response => response.data.ssh_key);
    }
    /**
     * Update ssh key
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'Renamed SSH Key'
     * };
     * const key = await client.ssh.updateKey('id-or-fingerprint', request);
     * ```
     */
    updateKey(idOrFingerprint, key) {
        return axios_instance_1.instance
            .put(`/account/keys/${idOrFingerprint}`, key)
            .then(response => response.data.ssh_key);
    }
    /**
     * Delete ssh key
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.ssh.deleteKey('id-or-fingerprint');
     * ```
     */
    deleteKey(idOrFingerprint) {
        return axios_instance_1.instance.delete(`/account/keys/${idOrFingerprint}`);
    }
}
exports.SshService = SshService;
//# sourceMappingURL=ssh.service.js.map