import { Tag } from '../../models/tag';
export declare class TagService {
    /**
     * Create new tag
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const tag = await client.tags.createTag('new-tag');
     * ```
     */
    createTag(name: string): Promise<Tag>;
    /**
     * Get all tags on the account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const tags = await client.tags.getTags();
     * ```
     */
    getTags(): Promise<Tag>;
    /**
     * Get a specific existing tag by name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const tag = await client.tags.getTagByName('tag-name');
     * ```
     */
    getTagByName(tagName: string): Promise<Tag>;
    /**
     * Add tag to specified resources
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const resources = [
     *    'droplet-id-1',
     *    'droplet-id-2',
     *    'droplet-id-3'
     * ];
     * await client.tags.tagResources('tag-name', resources);
     * ```
     */
    tagResources(tagName: string, resourceIds: string[]): Promise<void>;
    /**
     * Remove tag from specified resources
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const resources = [
     *    'droplet-id-1',
     *    'droplet-id-2',
     *    'droplet-id-3'
     * ];
     * await client.tags.removeTagFromResources('tag-name', resources);
     * ```
     */
    removeTagFromResources(tagName: string, resourceIds: string[]): Promise<void>;
    /**
     * Delete a tag by tag name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.tags.deleteTag('tag-name');
     * ```
     */
    deleteTag(tagName: string): Promise<void>;
}
