"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagService = void 0;
const axios_instance_1 = require("../../axios-instance");
class TagService {
    /**
     * Create new tag
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const tag = await client.tags.createTag('new-tag');
     * ```
     */
    createTag(name) {
        return axios_instance_1.instance.post(`/tags`, { name }).then(response => response.data.tag);
    }
    /**
     * Get all tags on the account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const tags = await client.tags.getTags();
     * ```
     */
    getTags() {
        return axios_instance_1.instance.get(`/tags`).then(response => response.data.tags);
    }
    /**
     * Get a specific existing tag by name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const tag = await client.tags.getTagByName('tag-name');
     * ```
     */
    getTagByName(tagName) {
        return axios_instance_1.instance.get(`/tags/${tagName}`).then(response => response.data.tag);
    }
    /**
     * Add tag to specified resources
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const resources = [
     *    'droplet-id-1',
     *    'droplet-id-2',
     *    'droplet-id-3'
     * ];
     * await client.tags.tagResources('tag-name', resources);
     * ```
     */
    tagResources(tagName, resourceIds) {
        const resources = resourceIds.map(id => {
            return {
                resource_id: id,
                resource_type: 'droplet'
            };
        });
        return axios_instance_1.instance.post(`/tags/${tagName}/resources`, { resources });
    }
    /**
     * Remove tag from specified resources
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const resources = [
     *    'droplet-id-1',
     *    'droplet-id-2',
     *    'droplet-id-3'
     * ];
     * await client.tags.removeTagFromResources('tag-name', resources);
     * ```
     */
    removeTagFromResources(tagName, resourceIds) {
        const resources = resourceIds.map(id => {
            return {
                resource_id: id,
                resource_type: 'droplet'
            };
        });
        return axios_instance_1.instance.delete(`/tags/${tagName}/resources`, {
            data: { resources }
        });
    }
    /**
     * Delete a tag by tag name
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.tags.deleteTag('tag-name');
     * ```
     */
    deleteTag(tagName) {
        return axios_instance_1.instance.delete(`/tags/${tagName}`);
    }
}
exports.TagService = TagService;
//# sourceMappingURL=tag.service.js.map